All of lore.kernel.org
 help / color / mirror / Atom feed
From: Ivo van Doorn <ivdoorn@gmail.com>
To: "John W. Linville" <linville@tuxdriver.com>
Cc: rt2400-devel@lists.sourceforge.net, linux-wireless@vger.kernel.org
Subject: [PATCH 05/11] rt2x00: Don't kill guardian_urb when it wasn't created
Date: Tue, 3 Jun 2008 20:29:50 +0200	[thread overview]
Message-ID: <200806032029.51057.IvDoorn@gmail.com> (raw)
In-Reply-To: <200806032027.06094.IvDoorn@gmail.com>

This fixes a "BUG: unable to handle kernel paging request"
bug in rt73usb which was caused by killing the guardian_urb
while it had never been allocated for rt73usb.

Signed-off-by: Ivo van Doorn <IvDoorn@gmail.com>
---
 drivers/net/wireless/rt2x00/rt2x00usb.c |    5 ++++-
 1 files changed, 4 insertions(+), 1 deletions(-)

diff --git a/drivers/net/wireless/rt2x00/rt2x00usb.c b/drivers/net/wireless/rt2x00/rt2x00usb.c
index 52d12fd..36a087a 100644
--- a/drivers/net/wireless/rt2x00/rt2x00usb.c
+++ b/drivers/net/wireless/rt2x00/rt2x00usb.c
@@ -394,8 +394,11 @@ void rt2x00usb_disable_radio(struct rt2x00_dev *rt2x00dev)
 	}
 
 	/*
 	 * Kill guardian urb.
 	 */
+	if (!test_bit(DRIVER_REQUIRE_BEACON_GUARD, &rt2x00dev->flags))
+		return;
+
 	for (i = 0; i < rt2x00dev->bcn->limit; i++) {
 		bcn_priv = rt2x00dev->bcn->entries[i].priv_data;
 		if (bcn_priv->guardian_urb)
@@ -394,8 +394,11 @@ void rt2x00usb_disable_radio(struct rt2x00_dev *rt2x00dev)
 
 	/*
-	 * Kill guardian urb.
+	 * Kill guardian urb (if required by driver).
 	 */
-- 
1.5.5.3


  parent reply	other threads:[~2008-06-03 18:26 UTC|newest]

Thread overview: 21+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
     [not found] <200806032024.52931.IvDoorn@gmail.com>
2008-06-03 18:29 ` [PATCH 01/11] rt2x00: Calculate register offset during compile time Ivo van Doorn
2008-06-03 20:05   ` [PATCH 01/11 v2] " Ivo van Doorn
2008-06-03 20:32     ` Johannes Berg
2008-06-03 20:44       ` Ivo van Doorn
2008-06-03 20:45     ` [PATCH 01/11 v3] " Ivo van Doorn
2008-06-03 20:41       ` Johannes Berg
2008-06-03 21:18       ` Harvey Harrison
2008-06-03 22:10         ` Ivo van Doorn
     [not found] ` <200806032025.45029.IvDoorn@gmail.com>
2008-06-03 18:29   ` [PATCH 02/11] rt2x00: Fix compile-time ffs calculation macros Ivo van Doorn
2008-06-03 18:52     ` Johannes Berg
2008-06-03 20:02       ` Ivo van Doorn
     [not found]   ` <200806032026.16128.IvDoorn@gmail.com>
2008-06-03 18:29     ` [PATCH 03/11] rt2x00: Make rt2x00_set/get_field macros Ivo van Doorn
     [not found]     ` <200806032026.40506.IvDoorn@gmail.com>
2008-06-03 18:29       ` [PATCH 04/11] rt2x00: Restrict DMA to 32-bit addresses Ivo van Doorn
     [not found]       ` <200806032027.06094.IvDoorn@gmail.com>
2008-06-03 18:29         ` Ivo van Doorn [this message]
2008-06-03 20:02           ` [PATCH 05/11] rt2x00: Don't kill guardian_urb when it wasn't created Stefanik Gábor
     [not found]         ` <200806032027.27540.IvDoorn@gmail.com>
2008-06-03 18:29           ` [PATCH 06/11] rt2x00: Removed unused descriptor read in txdone Ivo van Doorn
     [not found]           ` <200806032027.47342.IvDoorn@gmail.com>
2008-06-03 18:29             ` [PATCH 07/11] rt2x00: Remove CTS/RTS check in tx() Ivo van Doorn
     [not found]             ` <200806032028.03154.IvDoorn@gmail.com>
2008-06-03 18:30               ` [PATCH 08/11] rt2x00: Move led initialization into function Ivo van Doorn
     [not found] ` <200806032028.21795.IvDoorn@gmail.com>
     [not found]   ` <200806032028.39575.IvDoorn@gmail.com>
2008-06-03 18:29     ` [PATCH 10/11] rt2x00: Fix queue initialization Ivo van Doorn
2008-06-03 18:29       ` [PATCH 11/11] rt2x00: Release rt2x00 2.1.7 Ivo van Doorn
2008-06-03 18:30   ` [PATCH 09/11] rt2x00: Cleanup/optimize set_state() function callback function Ivo van Doorn

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=200806032029.51057.IvDoorn@gmail.com \
    --to=ivdoorn@gmail.com \
    --cc=linux-wireless@vger.kernel.org \
    --cc=linville@tuxdriver.com \
    --cc=rt2400-devel@lists.sourceforge.net \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.